@@ -2,9 +2,8 @@
 Mineral Database
 ====================
 
-pyrolite includes a limited mineral database which is useful for
-for looking up endmember compositions. This part of the package is being actively
-developed, so expect expansions and improvements soon.
+pyrolite includes a limited mineral database which is useful for looking up endmember
+compositions.
 """
 import pandas as pd
 from pyrolite.mineral.mindb import (
