@@ -6,10 +6,20 @@ Todo
 * Make use of new ax.axline features (https://matplotlib.org/3.3.1/users/whats_new.html#new-axes-axline-method)
 """
 
-from .pearce import pearceThNbYb, pearceTiNbYb
-from .TAS import TAS
 from ...util.log import Handle
+from .feldspar import FeldsparTernary
+from .pearce import pearceThNbYb, pearceTiNbYb
+from .QAP import QAP
+from .TAS import TAS
+from .USDA_soil_texture import USDASoilTexture
 
 logger = Handle(__name__)
 
-__all__ = ["pearceThNbYb", "pearceTiNbYb", "TAS"]
+__all__ = [
+    "pearceThNbYb",
+    "pearceTiNbYb",
+    "TAS",
+    "USDASoilTexture",
+    "QAP",
+    "FeldsparTernary",
+]
