@@ -12,20 +12,22 @@ USE_PCOLOR : :class:`bool`
     of :func:`matplotlib.pyplot.pcolormesh`.
 """
 from sys import platform
+
 from ..log import Handle
 
 logger = Handle(__name__)
 
 if platform == "darwin":
-    logger.debug('Using TkAgg renderer for Mac.')
+    logger.debug("Using TkAgg renderer for Mac.")
     import matplotlib
-    matplotlib.use('TkAgg')
 
-from .style import DEFAULT_CONT_COLORMAP, DEFAULT_DISC_COLORMAP
+    matplotlib.use("TkAgg")
+
 from .density import USE_PCOLOR
+from .style import DEFAULT_CONT_COLORMAP, DEFAULT_DISC_COLORMAP
 
 FONTSIZE = 12
 
-from .export import save_figure, save_axes
+from .export import save_axes, save_figure
 
 __all__ = ["save_figure", "save_axes", "DEFAULT_CONT_COLORMAP", "DEFAULT_DISC_COLORMAP"]
