@@ -1,6 +1,9 @@
 import re
 import textwrap
+from string import ascii_lowercase
+
 import numpy as np
+
 from .log import Handle
 
 logger = Handle(__name__)
@@ -18,13 +21,13 @@ def to_width(multiline_string, width=79, **kwargs):
 
 def normalise_whitespace(strg):
     """Substitutes extra tabs, newlines etc. for a single space."""
-    return re.sub("\s+", " ", strg).strip()
+    return re.sub(r"\s+", " ", strg).strip()
 
 
 def remove_prefix(z, prefix):
     """Remove a specific prefix from the start of a string."""
     if z.startswith(prefix):
-        return re.sub("^{}".format(prefix), "", z)
+        return re.sub(r"^{}".format(prefix), "", z)
     else:
         return z
 
@@ -49,7 +52,7 @@ def titlecase(
     exceptions=["and", "in", "a"],
     abbrv=["ID", "IGSN", "CIA", "CIW", "PIA", "SAR", "SiTiIndex", "WIP"],
     capitalize_first=True,
-    split_on="[\.\s_-]+",
+    split_on=r"[\.\s_-]+",
     delim="",
 ):
     """
@@ -206,7 +209,7 @@ def parse_entry(
             return [entry]
 
 
-def split_records(data, delimiter="\r\n"):
+def split_records(data, delimiter=r"\r\n"):
     """
     Splits records in a csv where quotation marks are used.
     Splits on a delimiter followed by an even number of quotation marks.
@@ -230,8 +233,8 @@ def slugify(value, delim="-"):
     -------
     :class:`str`
     """
-    value = re.sub("[^\w\s-]", "", value).strip()
-    value = re.sub("[-\s]+", delim, value)
+    value = re.sub(r"[^\w\s-]", "", value).strip()
+    value = re.sub(r"[-\s]+", delim, value)
     return value
 
 
@@ -251,5 +254,11 @@ def int_to_alpha(num):
         Alpha-encoding of a small integer.
 
     """
-    alphas = [chr(i).lower() for i in range(65, 65 + 26)]
-    return alphas[num]
+    remainder = num
+    text = []
+    if num >= 26:
+        major = remainder // 26
+        text.append(ascii_lowercase[remainder // 26 - 1])
+        remainder -= major * 26
+    text.append(ascii_lowercase[remainder])
+    return "".join(text)
