@@ -1,5 +1,6 @@
 import numpy as np
 import pandas as pd
+
 from .log import Handle
 
 logger = Handle(__name__)
@@ -47,6 +48,6 @@ def scale(in_unit, target_unit="ppm"):
         scale = __UNITS__[in_unit] / __UNITS__[target_unit]
     else:
         unkn = [i for i in [in_unit, target_unit] if i not in __UNITS__]
-        logger.warning("Units not known: {}. Defaulting to unity.".format(unkn))
+        logger.info("Units not known: {}. Defaulting to unity.".format(unkn))
         scale = 1.0
     return scale
